==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-VE/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Activo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Activos',
    'created_at' 			=> 'Creado',
    'createuser' 			=> 'Crear Usuario',
    'deny'  				=> 'Denegar',
    'email'      			=> 'Correo electrónico',
    'employee_num'      	=> 'No. Empleado.',
    'first_name' 			=> 'Nombre',
    'groupnotes'			=> 'Selecciona grupo que se asigna al usuario, recuerda que el usuario tiene los permisos del grupo al que se asigna.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Hereda de',
    'job' 					=> 'Título profesional',
    'last_login'  			=> 'Último Inicio de Sesión',
    'last_name'  			=> 'Apellido',
    'location'  			=> 'Ubicación',
    'lock_passwords'		=> 'Los detalles de acceso no pueden ser cambiados en esta instalación.',
    'manager' 				=> 'Responsable',
    'managed_locations'     => 'Ubicaciones adminsitradas',
    'name' 					=> 'Nombre',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Contraseña',
    'password' 				=> 'Contraseña',
    'phone'  				=> 'Teléfono',
    'show_current'          => 'Mostrar Usuarios Actuales',
    'show_deleted'          => 'Mostrar Usuarios Eliminados',
    'title' 				=> 'Título',
	'to_restore_them'		=> 'para restaurarlos.',
    'updateuser' 			=> 'Actualizar Usuario',
    'username' 				=> 'Nombre de usuario',
	'user_deleted_text' 	=> 'Este usuario ha sido marcado como borrado.',
    'username_note' 		=> '(Esto es usado sólo para el enlace de Active Directory, no para iniciar sesión.)',
    'cloneuser'             => 'Clonar Usuario',
    'viewusers' 			=> 'Ver Usuarios',
);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-VE/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Activo',
    'allow'  				=> 'Permitir',
    'checkedout'  			=> 'Activos',
    'created_at' 			=> 'Creado',
    'createuser' 			=> 'Crear Usuario',
    'deny'  				=> 'Denegar',
    'email'      			=> 'Correo electrónico',
    'employee_num'      	=> 'No. Empleado.',
    'first_name' 			=> 'Nombre',
    'groupnotes'			=> 'Seleccione un grupo para asignar al usuario, recuerde que un usuario asume los permisos del grupo al que se le asigna. Use ctrl+click (o cmd+click en MacOS) para anular la selección de grupos.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Hereda de',
    'job' 					=> 'Cargo',
    'last_login'  			=> 'Último Inicio de Sesión',
    'last_name'  			=> 'Apellido',
    'location'  			=> 'Ubicación',
    'lock_passwords'		=> 'Los detalles de acceso no pueden ser cambiados en esta instalación.',
    'manager' 				=> 'Supervisor',
    'managed_locations'     => 'Ubicaciones adminsitradas',
    'managed_users'         => 'Usuarios gestionados',
    'name' 					=> 'Nombre',
    'nogroup'               => 'Aún no se han creado grupos. Para añadir uno, visite: ',
    'notes'                 => 'Notas',
    'password_confirm' 		=> 'Confirmar Contraseña',
    'password' 				=> 'Contraseña',
    'phone'  				=> 'Teléfono',
    'show_current'          => 'Mostrar Usuarios Actuales',
    'show_deleted'          => 'Mostrar Usuarios Eliminados',
    'title' 				=> 'Cargo',
	'to_restore_them'		=> 'para restaurarlos.',
    'total_assets_cost'     => "Coste total de activos",
    'updateuser' 			=> 'Actualizar Usuario',
    'username' 				=> 'Nombre de usuario',
	'user_deleted_text' 	=> 'Este usuario ha sido marcado como borrado.',
    'username_note' 		=> '(Esto es usado sólo para el enlace de Active Directory, no para iniciar sesión.)',
    'cloneuser'             => 'Clonar Usuario',
    'viewusers' 			=> 'Ver Usuarios',
);
